; PIO compatible header file STC15-F-L.asm 20210829.
; For use only with series STC15F10xx STC15F20xx STC15L10xx
; STC15L20xx IAP15F10xx IAP15F20xx IAP15L10xx IAP15L20xx
; IRC15F20xx IRC15F10xx IRC15L10xx IRC15L20xx MCUs.
; This header is for first generation simple STC15 MCUs
; and has been checked against the corresponding datasheet.

;.ifndef STC15_F_L_ASM
;.define STC15_F_L_ASM

; Special Function Register | POR Reset Value | Description

P0 .EQU 0x80                  ;1111,1111 Port 0
   RST     .EQU 0x80+0 ;Reset
   SYSclkO .EQU 0x80+0 ;System Clock Out
   P00 .EQU 0x80+0 ;Port 0 Bit 0
   P01 .EQU 0x80+1 ;Port 0 Bit 1
   P0_0 .EQU 0x80+0 ;Port 0 Bit 0
   P0_1 .EQU 0x80+1 ;Port 0 Bit 1

SP .EQU 0x81                  ;0000,0111 Stack Pointer

;DPTR .EQU 0x82                ;0000,0000 Data Pointer Word
DPL .EQU 0x82                 ;0000,0000 Data Pointer Low Byte

DPH .EQU 0x83                 ;0000,0000 Data Pointer High Byte

PCON .EQU 0x87                ;xx11,0000 Power Control Register
   IDL   = 0x01 ;Idle Mode Control
   PD    = 0x02 ;Power Down Mode Control
   GF0   = 0x04 ;User Defined Gereral Purpose Flag 0
   GF1   = 0x08 ;User Defined General Purpose Flag 1
   POF   = 0x10 ;Power On Flag
   LVDF  = 0x20 ;Low Voltage Detect Flag

TCON .EQU 0x88                ;0000,0000 T0/T1 Control Register
   IT0 .EQU 0x88+0 ;Interrupt 0 Type
   IE0 .EQU 0x88+1 ;Interrupt 0 Edge
   IT1 .EQU 0x88+2 ;Interrupt 1 Type
   IE1 .EQU 0x88+3 ;Interrupt 1 Edge
   TR0 .EQU 0x88+4 ;Timer 0 Run
   TF0 .EQU 0x88+5 ;Timer 0 Flag
   TR1 .EQU 0x88+6 ;Timer 1 Run
   TF1 .EQU 0x88+7 ;Timer 1 Flag

TMOD .EQU 0x89                ;0000,0000 T0/T1 Mode Register
   T0_M0   = 0x01 ;Timer 0 Mode 0
   T0_M1   = 0x02 ;Timer 0 Mode 1
   T0_M    = 0x03 ;Timer 0 Mode
   T0_CT   = 0x04 ;Timer 0 Counter Timer
   T0_GATE = 0x08 ;Timer 0 Gate
   T1_M0   = 0x10 ;Timer 1 Mode 0
   T1_M1   = 0x20 ;Timer 1 Mode 1
   T1_M    = 0x30 ;Timer 1 Mode
   T1_CT   = 0x40 ;Timer 1 Counter Timer
   T1_GATE = 0x80 ;Timer 1 Gate
   M00   = 0x01 ;Mode 0 Timer 0
   M10   = 0x02 ;Mode 1 Timer 0
   M0    = 0x03 ;Timer 0 Mode
   CT0   = 0x04 ;Counter Timer 0
   GATE0 = 0x08 ;Gate 0
   M01   = 0x10 ;Mode 1 Timer 1
   M11   = 0x20 ;Mode 1 Timer 1
   M1    = 0x30 ;Timer 1 Mode
   CT1   = 0x40 ;Counter Timer 1
   GATE1 = 0x80 ;Gate 1

TL0 .EQU 0x8A                 ;0000,0000 Timer 0 Low Byte
RL_TL0 .EQU 0x8A              ;0000,0000 Reload Timer 0 Low Byte

TL1 .EQU 0x8B                 ;0000,0000 Timer 1 Low Byte
RL_TL1 .EQU 0x8B              ;0000,0000 Reload Timer 1 Low Byte

TH0 .EQU 0x8C                 ;0000,0000 Timer 0 High Byte
RL_TH0 .EQU 0x8C              ;0000,0000 Reload Timer 0 High Byte

TH1 .EQU 0x8D                 ;0000,0000 Timer 1 High Byte
RL_TH1 .EQU 0x8D              ;0000,0000 Reload Timer 1 High Byte

AUXR .EQU 0x8E                ;00xx,xxxx Auxiliary Register
   T1x12     = 0x40 ;Timer 1 Clock x12 Prescaler Bypass
   T0x12     = 0x80 ;Timer 0 Clock x12 Prescaler Bypass

INT_CLKO .EQU 0x8F            ;x000,xx00 Interrupt and Clock Output Control Register
AUXR2 .EQU 0x8F               ;x000,xx00 Auxiliary Register 2
   T0CLKO  = 0x01 ;Timer 0 Clock Output Control
   T1CLKO  = 0x02 ;Timer 1 Clock Output Control
   EX2     = 0x10 ;External Interrupt 3 Enable
   EX3     = 0x20 ;External Interrupt 2 Enable
   EX4     = 0x40 ;External Interrupt 4 Enable

P1 .EQU 0x90                  ;1111,1111 Port 1
   ACH0 .EQU 0x90+0 ;ADC Channel 0
   ACH1 .EQU 0x90+1 ;ADC Channel 1
   ACH2 .EQU 0x90+2 ;ADC Channel 2
   ACH3 .EQU 0x90+3 ;ADC Channel 3
   ACH4 .EQU 0x90+4 ;ADC Channel 4
   ACH5 .EQU 0x90+5 ;ADC Channel 5
   ACH6 .EQU 0x90+6 ;ADC Channel 6
   ACH7 .EQU 0x90+7 ;ADC Channel 7
   ADC0 .EQU 0x90+0 ;AtoD Channel 0
   ADC1 .EQU 0x90+1 ;AtoD Channel 1
   ADC2 .EQU 0x90+2 ;AtoD Channel 2
   ADC3 .EQU 0x90+3 ;AtoD Channel 3
   ADC4 .EQU 0x90+4 ;AtoD Channel 4
   ADC5 .EQU 0x90+5 ;AtoD Channel 5
   ADC6 .EQU 0x90+6 ;AtoD Channel 6
   ADC7 .EQU 0x90+7 ;AtoD Channel 7
   AIN0 .EQU 0x90+0 ;Analog Input 0
   AIN1 .EQU 0x90+1 ;Analog Input 1
   AIN2 .EQU 0x90+2 ;Analog Input 2
   AIN3 .EQU 0x90+3 ;Analog Input 3
   AIN4 .EQU 0x90+4 ;Analog Input 4
   AIN5 .EQU 0x90+5 ;Analog Input 5
   AIN6 .EQU 0x90+6 ;Analog Input 6
   AIN7 .EQU 0x90+7 ;Analog Input 7
   P10 .EQU 0x90+0 ;Port 1 Bit 0
   P11 .EQU 0x90+1 ;Port 1 Bit 1
   P12 .EQU 0x90+2 ;Port 1 Bit 2
   P13 .EQU 0x90+3 ;Port 1 Bit 3
   P14 .EQU 0x90+4 ;Port 1 Bit 4
   P15 .EQU 0x90+5 ;Port 1 Bit 5
   P16 .EQU 0x90+6 ;Port 1 Bit 6
   P17 .EQU 0x90+7 ;Port 1 Bit 7
   P1_0 .EQU 0x90+0 ;Port 1 Bit 0
   P1_1 .EQU 0x90+1 ;Port 1 Bit 1
   P1_2 .EQU 0x90+2 ;Port 1 Bit 2
   P1_3 .EQU 0x90+3 ;Port 1 Bit 3
   P1_4 .EQU 0x90+4 ;Port 1 Bit 4
   P1_5 .EQU 0x90+5 ;Port 1 Bit 5
   P1_6 .EQU 0x90+6 ;Port 1 Bit 6
   P1_7 .EQU 0x90+7 ;Port 1 Bit 7

P1M1 .EQU 0x91                ;0000,0000 Port 1 Mode Register 1
   P10M1 = 0x01 ;Port 1 bit 0 Mode 1
   P11M1 = 0x02 ;Port 1 bit 1 Mode 1
   P12M1 = 0x04 ;Port 1 bit 2 Mode 1
   P13M1 = 0x08 ;Port 1 bit 3 Mode 1
   P14M1 = 0x10 ;Port 1 bit 4 Mode 1
   P15M1 = 0x20 ;Port 1 bit 5 Mode 1
   P16M1 = 0x40 ;Port 1 bit 6 Mode 1
   P17M1 = 0x80 ;Port 1 bit 7 Mode 1

P1M0 .EQU 0x92                ;0000,0000 Port 1 Mode Register 0
   P10M0 = 0x01 ;Port 1 bit 0 Mode 0
   P11M0 = 0x02 ;Port 1 bit 1 Mode 0
   P12M0 = 0x04 ;Port 1 bit 2 Mode 0
   P13M0 = 0x08 ;Port 1 bit 3 Mode 0
   P14M0 = 0x10 ;Port 1 bit 4 Mode 0
   P15M0 = 0x20 ;Port 1 bit 5 Mode 0
   P16M0 = 0x40 ;Port 1 bit 6 Mode 0
   P17M0 = 0x80 ;Port 1 bit 7 Mode 0

P0M1 .EQU 0x93                ;0000,0000 Port 0 Mode Register 1
   P00M1 = 0x01 ;Port 0 bit 0 Mode 1
   P01M1 = 0x02 ;Port 0 bit 1 Mode 1

P0M0 .EQU 0x94                ;0000,0000 Port 0 Mode Register 0
   P00M0 = 0x01 ;Port 0 bit 0 Mode 0
   P01M0 = 0x02 ;Port 0 bit 1 Mode 0

P2M1 .EQU 0x95                ;0000,0000 Port 2 Mode Register 1
   P20M1 = 0x01 ;Port 2 bit 0 Mode 1
   P21M1 = 0x02 ;Port 2 bit 1 Mode 1
   P22M1 = 0x04 ;Port 2 bit 2 Mode 1
   P23M1 = 0x08 ;Port 2 bit 3 Mode 1
   P24M1 = 0x10 ;Port 2 bit 4 Mode 1
   P25M1 = 0x20 ;Port 2 bit 5 Mode 1
   P26M1 = 0x40 ;Port 2 bit 6 Mode 1
   P27M1 = 0x80 ;Port 2 bit 7 Mode 1

P2M0 .EQU 0x96                ;0000,0000 Port 2 Mode Register 0
   P20M0 = 0x01 ;Port 2 bit 0 Mode 0
   P21M0 = 0x02 ;Port 2 bit 1 Mode 0
   P22M0 = 0x04 ;Port 2 bit 2 Mode 0
   P23M0 = 0x08 ;Port 2 bit 3 Mode 0
   P24M0 = 0x10 ;Port 2 bit 4 Mode 0
   P25M0 = 0x20 ;Port 2 bit 5 Mode 0
   P26M0 = 0x40 ;Port 2 bit 6 Mode 0
   P27M0 = 0x80 ;Port 2 bit 7 Mode 0

CLK_DIV .EQU 0x97             ;xxxx,x000 Clock Division Control Register
PCON2 .EQU 0x97               ;xxxx,x000 Power Control Register 2
   CLKS0 = 0x01 ;Clock Select 0
   CLKS1 = 0x02 ;Clock Select 1
   CLKS2 = 0x04 ;Clock Select 2
   CLKS  = 0x07 ;Clock Select

P1ASF .EQU 0x9D               ;0000,0000 Port 1 Analog Function Configuration Register
   P10ASF = 0x01 ;Port 1 bit 0 Analog Special Function
   P11ASF = 0x02 ;Port 1 bit 1 Analog Special Function
   P12ASF = 0x04 ;Port 1 bit 2 Analog Special Function
   P13ASF = 0x08 ;Port 1 bit 3 Analog Special Function
   P14ASF = 0x10 ;Port 1 bit 4 Analog Special Function
   P15ASF = 0x20 ;Port 1 bit 5 Analog Special Function
   P16ASF = 0x40 ;Port 1 bit 6 Analog Special Function
   P17ASF = 0x80 ;Port 1 bit 7 Analog Special Function

P2 .EQU 0xA0                  ;1111,1111 Port 2
   RSTOUT_LOW .EQU 0xA0+0 ;Reset Out Low
   P20 .EQU 0xA0+0 ;Port 2 Bit 0
   P21 .EQU 0xA0+1 ;Port 2 Bit 1
   P22 .EQU 0xA0+2 ;Port 2 Bit 2
   P23 .EQU 0xA0+3 ;Port 2 Bit 3
   P24 .EQU 0xA0+4 ;Port 2 Bit 4
   P25 .EQU 0xA0+5 ;Port 2 Bit 5
   P26 .EQU 0xA0+6 ;Port 2 Bit 6
   P27 .EQU 0xA0+7 ;Port 2 Bit 7
   P2_0 .EQU 0xA0+0 ;Port 2 Bit 0
   P2_1 .EQU 0xA0+1 ;Port 2 Bit 1
   P2_2 .EQU 0xA0+2 ;Port 2 Bit 2
   P2_3 .EQU 0xA0+3 ;Port 2 Bit 3
   P2_4 .EQU 0xA0+4 ;Port 2 Bit 4
   P2_5 .EQU 0xA0+5 ;Port 2 Bit 5
   P2_6 .EQU 0xA0+6 ;Port 2 Bit 6
   P2_7 .EQU 0xA0+7 ;Port 2 Bit 7

IE .EQU 0xA8                  ;000x,0000 Interrupt Control Register
   EX0  .EQU 0xA8+0 ;Enable External 0
   ET0  .EQU 0xA8+1 ;Enable Timer 0
   EX1  .EQU 0xA8+2 ;Enable External 1
   ET1  .EQU 0xA8+3 ;Enable Timer 1
   EADC .EQU 0xA8+5 ;Enable ADC
   ELVD .EQU 0xA8+6 ;Enable Low Voltage Detect
   EA   .EQU 0xA8+7 ;Enable All

WKTCL .EQU 0xAA               ;0111,1111|1111,1111 Power Down Wakeup Timer Control Low Byte
WKTCL_CNT .EQU 0xAA           ;0111,1111|1111,1111 Power Down Wakeup Timer Control Count

WKTCH .EQU 0xAB               ;0111,1111 Power Down Wakeup Timer Control High Byte
   WKTEN = 0x80 ;Power Down Wakeup Timer Enable
WKTCH_CNT .EQU 0xAB           ;0111,1111|x111,1111 Power Down Wakeup Timer Control Count


P3 .EQU 0xB0                  ;1111,1111 Port 3
   INT4    .EQU 0xB0+0 ;Interrupt 4
   INT0    .EQU 0xB0+2 ;Interrupt 0
   INT1    .EQU 0xB0+3 ;Interrupt 1
   T0      .EQU 0xB0+4 ;Timer 0
   CLKOUT1 .EQU 0xB0+4 ;Clock Out 1
   T1      .EQU 0xB0+5 ;Timer 1
   CLKOUT2 .EQU 0xB0+5 ;Clock Out 0
   INT2    .EQU 0xB0+6 ;Interrupt 2
   INT3    .EQU 0xB0+7 ;Interrupt 3
   P30 .EQU 0xB0+0 ;Port 3 Bit 0
   P31 .EQU 0xB0+1 ;Port 3 Bit 1
   P32 .EQU 0xB0+2 ;Port 3 Bit 2
   P33 .EQU 0xB0+3 ;Port 3 Bit 3
   P34 .EQU 0xB0+4 ;Port 3 Bit 4
   P35 .EQU 0xB0+5 ;Port 3 Bit 5
   P36 .EQU 0xB0+6 ;Port 3 Bit 6
   P37 .EQU 0xB0+7 ;Port 3 Bit 7
   P3_0 .EQU 0xB0+0 ;Port 3 Bit 0
   P3_1 .EQU 0xB0+1 ;Port 3 Bit 1
   P3_2 .EQU 0xB0+2 ;Port 3 Bit 2
   P3_3 .EQU 0xB0+3 ;Port 3 Bit 3
   P3_4 .EQU 0xB0+4 ;Port 3 Bit 4
   P3_5 .EQU 0xB0+5 ;Port 3 Bit 5
   P3_6 .EQU 0xB0+6 ;Port 3 Bit 6
   P3_7 .EQU 0xB0+7 ;Port 3 Bit 7

P3M1 .EQU 0xB1                ;0000,0000 Port 3 Mode Register 1
   P30M1 = 0x01 ;Port 3 bit 0 Mode 1
   P31M1 = 0x02 ;Port 3 bit 1 Mode 1
   P32M1 = 0x04 ;Port 3 bit 2 Mode 1
   P33M1 = 0x08 ;Port 3 bit 3 Mode 1
   P34M1 = 0x10 ;Port 3 bit 4 Mode 1
   P35M1 = 0x20 ;Port 3 bit 5 Mode 1
   P36M1 = 0x40 ;Port 3 bit 6 Mode 1
   P37M1 = 0x80 ;Port 3 bit 7 Mode 1

P3M0 .EQU 0xB2                ;0000,0000 Port 3 Mode Register 0
   P30M0 = 0x01 ;Port 3 bit 0 Mode 0
   P31M0 = 0x02 ;Port 3 bit 1 Mode 0
   P32M0 = 0x04 ;Port 3 bit 2 Mode 0
   P33M0 = 0x08 ;Port 3 bit 3 Mode 0
   P34M0 = 0x10 ;Port 3 bit 4 Mode 0
   P35M0 = 0x20 ;Port 3 bit 5 Mode 0
   P36M0 = 0x40 ;Port 3 bit 6 Mode 0
   P37M0 = 0x80 ;Port 3 bit 7 Mode 0

IP .EQU 0xB8                  ;x00x,0000|x0x0,0000 Interrupt Priority Register
   PX0  .EQU 0xB8+0 ;Priority External 0
   PT0  .EQU 0xB8+1 ;Priority Timer 0
   PX1  .EQU 0xB8+2 ;Priority External 1
   PT1  .EQU 0xB8+3 ;Priority Timer 1
   PADC .EQU 0xB8+5 ;Priority ADC
   PLVD .EQU 0xB8+6 ;Priority Low Voltage Detect

IRC_CLKO .EQU 0xBB            ;0xxx,0xxx Internal RC Clock Output Control Register
   DIVIRCO = 0x08 ;Divide Internal Resistor Capacitor Clock Ouptur
   EN_IRCO = 0x80 ;Enable Internal Resistor Capacitor Clock Output

ADC_CONTR .EQU 0xBC           ;0000,0000 ADC Conversion Control Register
   CHS0      = 0x01 ;Channel Select 0
   CHS1      = 0x02 ;Channel Select 1
   CHS2      = 0x04 ;Channel Select 2
   ADC_CHS   = 0x0F ;ADC Analog Channel Select
   ADC_START = 0x08 ;Analog to Digital Converter Start
   ADC_FLAG  = 0x10 ;Analog to Digital Converter Flag
   SPEED0    = 0x20 ;Speed 0
   SPEED1    = 0x40 ;Speed 1
   ADC_POWER = 0x80 ;Analog to Digital Converter Power

ADC_RES .EQU 0xBD             ;0000,0000 ADC Conversion Result High 8 Bits

ADC_RESL .EQU 0xBE            ;0000,0000 ADC Conversion Result Low 2 Bits

WDT_CONTR .EQU 0xC1           ;0x00,0000 Watchdog Control Register
   PS0      = 0x01 ;Watchdog Timer Prescaler 0
   PS1      = 0x02 ;Watchdog Timer Prescaler 1
   PS2      = 0x04 ;Watchdog Timer Prescaler 2
   WDTPS0   = 0x01 ;Watchdog Timer Prescaler 0
   WDTPS1   = 0x02 ;Watchdog Timer Prescaler 1
   WDTPS2   = 0x04 ;Watchdog Timer Prescaler 2
   WDT_PS   = 0x07 ;Watchdog Timer Prescaler
   IDL_WDT  = 0x08 ;Watchdog Timer Idle Mode Behavior
   CLR_WDT  = 0x10 ;Clear Watchdog Timer
   EN_WDT   = 0x20 ;Enable Watchdog Timer
   WDT_FLAG = 0x80 ;Watchdog Timer Overflow Flag

IAP_DATA .EQU 0xC2            ;1111,1111 In Application Programming Data
ISP_DATA .EQU 0xC2            ;1111,1111 In System Programming Data

IAP_ADDRH .EQU 0xC3           ;0000,0000 In Application Programming Address High
ISP_ADDRH .EQU 0xC3           ;0000,0000 In System Programming Address High

IAP_ADDRL .EQU 0xC4           ;0000,0000 In Application Programming Address Low
ISP_ADDRL .EQU 0xC4           ;0000,0000 In System Programming Address Low

IAP_CMD .EQU 0xC5             ;xxxx,x000|xxxx,xx00 In Application Programming Command
ISP_CMD .EQU 0xC5             ;xxxx,x000|xxxx,xx00 In System Programming Command
   MS0    = 0x01 ;Mode Select 0
   MS1    = 0x02 ;Mode Select 1
   IAPCMD = 0x03 ;In Application Programming Command
; Valid commands follow
   IAP_IDL   = 0x00
   IAP_READ  = 0x01
   IAP_WRITE = 0x02
   IAP_ERASE = 0x03
; End of valid commands

IAP_TRIG .EQU 0xC6            ;xxxx,xxxx In Application Programming Trigger
ISP_TRIG .EQU 0xC6            ;xxxx,xxxx In System Programming Trigger

IAP_CONTR .EQU 0xC7           ;0000,0000 In Application Programming Control
ISP_CONTR .EQU 0xC7           ;0000,00x0|0000,0000 In System Programming Control
   WT0      = 0x01 ;Wait 0
   WT1      = 0x02 ;Wait 1
   WT2      = 0x04 ;Wait 2
   IAP_WT   = 0x07 ;In Application Programming Wait
   CMD_FAIL = 0x10 ;Command Fail
   SWRST    = 0x20 ;Software Reset Trigger
   SWBS     = 0x40 ;Software Boot Selection
   IAPEN    = 0x80 ;In Application Programming Enable

PSW .EQU 0xD0                 ;0000,00x0 Program status word
   P   .EQU 0xD0+0 ;Parity
; SBIT(F1,  0xD0, 1); //Flag 1
   OV  .EQU 0xD0+2 ;Overflow
   RS0 .EQU 0xD0+3 ;Register Select 0
   RS1 .EQU 0xD0+4 ;Register Select 1
   F0  .EQU 0xD0+5 ;Flag 0
   AC  .EQU 0xD0+6 ;Auxiliary Carry
   CY  .EQU 0xD0+7 ;Carry

ACC .EQU 0xE0                 ;0000,0000 Accumulator
   ACC0 .EQU 0xE0+0 ;Accumulator Bit 0
   ACC1 .EQU 0xE0+1 ;Accumulator Bit 1
   ACC2 .EQU 0xE0+2 ;Accumulator Bit 2
   ACC3 .EQU 0xE0+3 ;Accumulator Bit 3
   ACC4 .EQU 0xE0+4 ;Accumulator Bit 4
   ACC5 .EQU 0xE0+5 ;Accumulator Bit 5
   ACC6 .EQU 0xE0+6 ;Accumulator Bit 6
   ACC7 .EQU 0xE0+7 ;Accumulator Bit 7
   ACC_0 .EQU 0xE0+0 ;Accumulator Bit 0
   ACC_1 .EQU 0xE0+1 ;Accumulator Bit 1
   ACC_2 .EQU 0xE0+2 ;Accumulator Bit 2
   ACC_3 .EQU 0xE0+3 ;Accumulator Bit 3
   ACC_4 .EQU 0xE0+4 ;Accumulator Bit 4
   ACC_5 .EQU 0xE0+5 ;Accumulator Bit 5
   ACC_6 .EQU 0xE0+6 ;Accumulator Bit 6
   ACC_7 .EQU 0xE0+7 ;Accumulator Bit 7

B .EQU 0xF0                   ;0000,0000 B Register
   B0 .EQU 0xF0+0 ;B Bit 0
   B1 .EQU 0xF0+1 ;B Bit 1
   B2 .EQU 0xF0+2 ;B Bit 2
   B3 .EQU 0xF0+3 ;B Bit 3
   B4 .EQU 0xF0+4 ;B Bit 4
   B5 .EQU 0xF0+5 ;B Bit 5
   B6 .EQU 0xF0+6 ;B Bit 6
   B7 .EQU 0xF0+7 ;B Bit 7
   B_0 .EQU 0xF0+0 ;B Bit 0
   B_1 .EQU 0xF0+1 ;B Bit 1
   B_2 .EQU 0xF0+2 ;B Bit 2
   B_3 .EQU 0xF0+3 ;B Bit 3
   B_4 .EQU 0xF0+4 ;B Bit 4
   B_5 .EQU 0xF0+5 ;B Bit 5
   B_6 .EQU 0xF0+6 ;B Bit 6
   B_7 .EQU 0xF0+7 ;B Bit 7

;Interrupt_Address = ( Interrupt_Number * 8 ) + 3
;Vectors are named after their corresponding IE, IP or IR register bit so
;that we don't have to invent names and can be more consistent across MCUs.
   X0_VECTOR  = 0  ; 0x03 External Interrupt 0
   T0_VECTOR  = 1  ; 0x0B Timer 0
   X1_VECTOR  = 2  ; 0x13 External Interrupt 1
   T1_VECTOR  = 3  ; 0x1B Timer 1
   ;    -     = 4  ; 0x23        -
   ADC_VECTOR = 5  ; 0x2B Analog to Digital Converter
   LVD_VECTOR = 6  ; 0x33 Low Voltage Detect
   ;    -     = 7  ; 0x3B        -
   ;    -     = 8  ; 0x43        -
   ;    -     = 9  ; 0x4B        -
   X2_VECTOR  = 10 ; 0x53 External Interrupt 2
   X3_VECTOR  = 11 ; 0x5B External Interrupt 3
   ;    -     = 12 ; 0x63        -
   ;    -     = 13 ; 0x6B        -
   ;          = 14 ; 0x73 System Reserved
   ;          = 15 ; 0x7B System Reserved
   X4_VECTOR  = 16 ; 0x83 External Interrupt 4

;.endif
